@@ -1,5 +1,85 @@
 var NAVTREEINDEX17 =
 {
+"structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392":[10,7,0,1,0],
+"structpw__client__node__buffer.html#a1d524a38ed82fb88371d741bcb1e3ff0":[10,7,0,1,1],
+"structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3":[10,7,0,1,3],
+"structpw__client__node__events.html":[10,7,0,2],
+"structpw__client__node__events.html#a0942c754a0fd77db7c9051172b2ac991":[10,7,0,2,10],
+"structpw__client__node__events.html#a0fdb140f41117e7690aca449844d72c2":[10,7,0,2,9],
+"structpw__client__node__events.html#a3802ec24f1305664c8d1b846abc244c8":[10,7,0,2,7],
+"structpw__client__node__events.html#a3d12bf0a63aba14bc897e4ceb51e4fe4":[10,7,0,2,0],
+"structpw__client__node__events.html#a63c10e914836b4c4ffc02be889c717f8":[10,7,0,2,8],
+"structpw__client__node__events.html#a775ca4ec6d6115039b2e8574bef184f2":[10,7,0,2,4],
+"structpw__client__node__events.html#aa25eeb692995699b672f71251ec0b4b6":[10,7,0,2,11],
+"structpw__client__node__events.html#ab1aba9806056fc945c2328f1cc128f6e":[10,7,0,2,12],
+"structpw__client__node__events.html#abac4b80ae987a95a81ece32baa8fef14":[10,7,0,2,5],
+"structpw__client__node__events.html#abb5194c288d8bb436b1c8264e21037c7":[10,7,0,2,3],
+"structpw__client__node__events.html#ac0b5a3c66103be01b784464d4dd81fa0":[10,7,0,2,6],
+"structpw__client__node__events.html#ac5884f60926b382728097c8846dcba85":[10,7,0,2,2],
+"structpw__client__node__events.html#ad7084094ae633b01409033ba363ef78b":[10,7,0,2,1],
+"structpw__client__node__methods.html":[10,7,0,3],
+"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740":[10,7,0,3,6],
+"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e":[10,7,0,3,1],
+"structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404":[10,7,0,3,2],
+"structpw__client__node__methods.html#a1db43e226468e68a6a52292aa6a894c6":[10,7,0,3,7],
+"structpw__client__node__methods.html#acf64a3bd71fd790592e41458a4793c62":[10,7,0,3,0],
+"structpw__client__node__methods.html#ae7a71dd91cda53767aa31aa10c050244":[10,7,0,3,5],
+"structpw__client__session.html":[10,7,4,23],
+"structpw__client__session__events.html":[10,7,4,8],
+"structpw__client__session__events.html#a6005c505de498fbaaaed2dd87918773f":[10,7,4,8,0],
+"structpw__client__session__events.html#a8e823bcde1844c0857314b10069f3b8d":[10,7,4,8,1],
+"structpw__client__session__events.html#aae0dc344c9b1d62b21fb16e4fc2c9c33":[10,7,4,8,3],
+"structpw__client__session__events.html#af3eab807465363845550f89f1bb9d816":[10,7,4,8,2],
+"structpw__client__session__methods.html":[10,7,4,9],
+"structpw__client__session__methods.html#a4537bb47cfe11b27649ffe082fdd49fa":[10,7,4,9,0],
+"structpw__client__session__methods.html#a54ba399f450c8ee5b85cfba7ad4b352a":[10,7,4,9,1],
+"structpw__context.html":[10,4,2,3],
+"structpw__context__events.html":[10,4,2,1],
+"structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d":[10,4,2,1,4],
+"structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e":[10,4,2,1,1],
+"structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0":[10,4,2,1,5],
+"structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[10,4,2,1,2],
+"structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[10,4,2,1,0],
+"structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,4,2,1,3],
+"structpw__control.html":[10,5,8,4],
+"structpw__control.html":[10,5,10,2],
+"structpw__control__events.html":[10,5,10,1],
+"structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[10,5,10,1,4],
+"structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,5,10,1,0],
+"structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa":[10,5,10,1,2],
+"structpw__control__events.html#ad23091c8931adf9aa85564b31e2d9ca8":[10,5,10,1,1],
+"structpw__control__events.html#adbd47ebc650888ca6235b763fa3f6ef2":[10,5,10,1,3],
+"structpw__core.html":[10,4,4,4],
+"structpw__core__events.html":[10,4,4,2],
+"structpw__core__events.html#a20931e5073a743e26c70957f85c10fd8":[10,4,4,2,3],
+"structpw__core__events.html#a28cd6e2263efb69df702822028a45df2":[10,4,4,2,8],
+"structpw__core__events.html#a590bf80a38429eef4a94d2e8b7f82e56":[10,4,4,2,4],
+"structpw__core__events.html#a7c1f8bd6078afab78aa943704efe7131":[10,4,4,2,7],
+"structpw__core__events.html#a8433a5ea5115e8d914a70ba5dacd3b81":[10,4,4,2,1],
+"structpw__core__events.html#a8a700a03453729d52d96112647125303":[10,4,4,2,5],
+"structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7":[10,4,4,2,0],
+"structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976":[10,4,4,2,6],
+"structpw__core__events.html#acc0442d3b7d94005c8c63e5bd7b89473":[10,4,4,2,2],
+"structpw__core__info.html":[10,4,4,1],
+"structpw__core__info.html#a25d93390dbafcb433827ec29c195404f":[10,4,4,1,5],
+"structpw__core__info.html#a3e394e50023a597dafb391887249d4eb":[10,4,4,1,4],
+"structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083":[10,4,4,1,1],
+"structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca":[10,4,4,1,0],
+"structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42":[10,4,4,1,2],
+"structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f":[10,4,4,1,3],
+"structpw__core__methods.html":[10,4,4,3],
+"structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703":[10,4,4,3,1],
+"structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9":[10,4,4,3,4],
+"structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309":[10,4,4,3,8],
+"structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5":[10,4,4,3,2],
+"structpw__core__methods.html#a570886edc43416b3dcd10b48016493af":[10,4,4,3,6],
+"structpw__core__methods.html#a7e70c82277387a47a953d64b0ba82cce":[10,4,4,3,7],
+"structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa":[10,4,4,3,5],
+"structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176":[10,4,4,3,3],
+"structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a":[10,4,4,3,0],
+"structpw__data__loop.html":[10,5,11,2],
+"structpw__data__loop__events.html":[10,5,11,1],
+"structpw__data__loop__events.html#a19c5624deda8fb2d4fd452bf6ba6c3b8":[10,5,11,1,0],
 "structpw__data__loop__events.html#a5ee1e79472b7ab5aab28d40df7a1db0b":[10,5,11,1,1],
 "structpw__device.html":[10,4,5,4],
 "structpw__device__events.html":[10,4,5,2],
@@ -112,15 +192,15 @@ var NAVTREEINDEX17 =
 "structpw__filter__events.html#aca5d0df9b247219e850a94be2bf9d135":[10,1,1,5],
 "structpw__filter__events.html#adb8416b044c19f8856dac1d2b554f32a":[10,1,1,1],
 "structpw__filter__events.html#afb8a57497ec76189b2fd247ce72966c5":[10,1,1,2],
-"structpw__global.html":[10,4,2,4],
 "structpw__global.html":[10,5,12,2],
+"structpw__global.html":[10,4,2,4],
 "structpw__global__events.html":[10,5,12,1],
 "structpw__global__events.html#a57040ccb9805bda67581693d06c0cea6":[10,5,12,1,2],
 "structpw__global__events.html#a8ccd4e331a4c1a0401e13ab3c9b04236":[10,5,12,1,1],
 "structpw__global__events.html#a909a601dfd3ce02c04c0e714df6450a1":[10,5,12,1,0],
 "structpw__global__events.html#a914924700d817cb9d4f58c327d5952e8":[10,5,12,1,3],
-"structpw__impl__client.html":[10,5,0,2],
 "structpw__impl__client.html":[10,4,2,5],
+"structpw__impl__client.html":[10,5,0,2],
 "structpw__impl__client__events.html":[10,5,0,1],
 "structpw__impl__client__events.html#a046e956441b5395308c8ff140292dfee":[10,5,0,1,7],
 "structpw__impl__client__events.html#a30be6d32c40038f0ae9dfdbccdf74e1b":[10,5,0,1,0],
@@ -152,8 +232,8 @@ var NAVTREEINDEX17 =
 "structpw__impl__factory__implementation.html":[10,5,3,2],
 "structpw__impl__factory__implementation.html#a99eef2345bd7b402f47ad72beb6ebfe7":[10,5,3,2,1],
 "structpw__impl__factory__implementation.html#ab63e939995687efd690f736730021e7f":[10,5,3,2,0],
-"structpw__impl__link.html":[10,5,4,2],
 "structpw__impl__link.html":[10,5,8,3],
+"structpw__impl__link.html":[10,5,4,2],
 "structpw__impl__link__events.html":[10,5,4,1],
 "structpw__impl__link__events.html#a05b20c99f1014e62e0d032b92382f584":[10,5,4,1,5],
 "structpw__impl__link__events.html#a05c9fec1c6580f673d09e33005bca5ee":[10,5,4,1,0],
@@ -169,85 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__impl__metadata__events.html#a75ce933b493a16ecad3e8f9834cc74e6":[10,5,5,1,2],
 "structpw__impl__metadata__events.html#ac11ef017d8f59e0a28d1d882ac508b22":[10,5,5,1,0],
 "structpw__impl__module.html":[10,5,6,2],
-"structpw__impl__module__events.html":[10,5,6,1],
-"structpw__impl__module__events.html#a1f0de76c49fdf742fe40c6fc0799d08c":[10,5,6,1,3],
-"structpw__impl__module__events.html#a2cb2abff60d0fa2370afcb8b5c2ae830":[10,5,6,1,2],
-"structpw__impl__module__events.html#a4cfcceec669bbbdf6697e36cd5dbae1d":[10,5,6,1,1],
-"structpw__impl__module__events.html#a75c9588d21472e8d610b813bdd9a419e":[10,5,6,1,4],
-"structpw__impl__module__events.html#aea5e86ba050b1b9e92bb3c7ba3425f71":[10,5,6,1,0],
-"structpw__impl__node.html":[10,5,7,2],
-"structpw__impl__node__events.html":[10,5,7,1],
-"structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18":[10,5,7,1,16],
-"structpw__impl__node__events.html#a16b71cb7eece2a1b7b2d89007357238b":[10,5,7,1,10],
-"structpw__impl__node__events.html#a21b4486448a26b56eea0508a92c99035":[10,5,7,1,1],
-"structpw__impl__node__events.html#a347372b746a4f05fc0a6d8ecb1346dd6":[10,5,7,1,4],
-"structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f":[10,5,7,1,15],
-"structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463":[10,5,7,1,12],
-"structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430":[10,5,7,1,0],
-"structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a":[10,5,7,1,2],
-"structpw__impl__node__events.html#a8a268deab9a29164fc8f9b57a9ee55e7":[10,5,7,1,8],
-"structpw__impl__node__events.html#a8a7823893c92e2d190c14aa220b71be8":[10,5,7,1,9],
-"structpw__impl__node__events.html#a8aa906ff5f65e321b1e500979cd1d748":[10,5,7,1,6],
-"structpw__impl__node__events.html#a912be8dba73d32a813f2a00576384fa3":[10,5,7,1,13],
-"structpw__impl__node__events.html#a9b2f9b0790584b2ee32e0ee46d9e0c5e":[10,5,7,1,7],
-"structpw__impl__node__events.html#aaf15bbdebaa2b67dd31ba4c3d56cebc6":[10,5,7,1,5],
-"structpw__impl__node__events.html#abae73b060850e69368efdace5e1ddd68":[10,5,7,1,3],
-"structpw__impl__node__events.html#ac82d3cde1bc6a6b7a617f80b74c8dc9e":[10,5,7,1,14],
-"structpw__impl__node__events.html#adbaa329398d27871d25ddacad8a33c12":[10,5,7,1,11],
-"structpw__impl__port.html":[10,5,7,3],
-"structpw__impl__port.html":[10,5,4,3],
-"structpw__impl__port.html":[10,5,8,2],
-"structpw__impl__port__events.html":[10,5,8,1],
-"structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82":[10,5,8,1,8],
-"structpw__impl__port__events.html#a5595c734ed5c3fc9ab27c2f5244fa325":[10,5,8,1,1],
-"structpw__impl__port__events.html#a69e18fd1facb78dbb42025c17ef0884a":[10,5,8,1,4],
-"structpw__impl__port__events.html#a7049ef85f5a0f35988c6a2f60a02c385":[10,5,8,1,2],
-"structpw__impl__port__events.html#a73104e5c2b8f887977945a597fa6b1ee":[10,5,8,1,5],
-"structpw__impl__port__events.html#a74130c25a3cc6e05ef753847e17a85cb":[10,5,8,1,11],
-"structpw__impl__port__events.html#a77a67b128bc4961a1caa38572f8f6094":[10,5,8,1,7],
-"structpw__impl__port__events.html#a7d76d0a7bef38963ff7c3e5a4fd9a1d3":[10,5,8,1,0],
-"structpw__impl__port__events.html#a8d5a42f37e97b448cf6e1d7942677c81":[10,5,8,1,10],
-"structpw__impl__port__events.html#a8ddfb5c4f95dafcf15e0e9d3df367169":[10,5,8,1,3],
-"structpw__impl__port__events.html#a9f23250e31672a49aa26a5dd5b593e80":[10,5,8,1,9],
-"structpw__impl__port__events.html#acae053d6b84259d9a475eda14ca670ed":[10,5,8,1,6],
-"structpw__link.html":[10,4,7,4],
-"structpw__link__events.html":[10,4,7,2],
-"structpw__link__events.html#a36fd833d967b2b648424449197eb95c5":[10,4,7,2,0],
-"structpw__link__events.html#a4f9f823d13092e197c89c151ea21b27b":[10,4,7,2,1],
-"structpw__link__info.html":[10,4,7,1],
-"structpw__link__info.html#a0513f644f43b252a0e068e09c8452382":[10,4,7,1,2],
-"structpw__link__info.html#a0c7b378ed65b5311702cd2b693d6b819":[10,4,7,1,0],
-"structpw__link__info.html#a274785180186fbe127e48715092d775a":[10,4,7,1,5],
-"structpw__link__info.html#a5a21130d91e20dafc4ce1b09b7c30aca":[10,4,7,1,1],
-"structpw__link__info.html#a64ff3f8d01d62e5e2ed86933fd6b15e1":[10,4,7,1,6],
-"structpw__link__info.html#a98d810a2a69da694add77f70b2f86061":[10,4,7,1,7],
-"structpw__link__info.html#ad4e7766ec44b62455169b916c3cdbbb1":[10,4,7,1,3],
-"structpw__link__info.html#ae62f88ba3c96b5465a0b046ce93acdd5":[10,4,7,1,8],
-"structpw__link__info.html#afaa2ba4fad6933cc019375c14f103120":[10,4,7,1,4],
-"structpw__link__methods.html":[10,4,7,3],
-"structpw__link__methods.html#a93094b3a43a3dd5911e6016f1cbd44cf":[10,4,7,3,0],
-"structpw__link__methods.html#ae0864a9eb97073db8174b051b074f180":[10,4,7,3,1],
-"structpw__loop.html":[10,4,8,1],
-"structpw__loop.html#a4624741580712c167c17bd9242be003f":[10,4,8,1,1],
-"structpw__loop.html#a639de0bfd74cf9e292932aaed15182c5":[10,4,8,1,2],
-"structpw__loop.html#abab71679705176a16c9e27b3115701c3":[10,4,8,1,0],
-"structpw__main__loop.html":[10,4,1,2],
-"structpw__main__loop__events.html":[10,4,1,1],
-"structpw__main__loop__events.html#a1713b16265dcafb5944612c5d653a553":[10,4,1,1,1],
-"structpw__main__loop__events.html#abbfcaf5cd47f231f25979949df15cf29":[10,4,1,1,0],
-"structpw__map.html":[10,6,4,1],
-"structpw__map.html#a6fc621171dbc57de8c44d26f639d2f1b":[10,6,4,1,0],
-"structpw__map.html#acf2ad4417afa20b00e4a1f3837573d87":[10,6,4,1,1],
-"structpw__map__range.html":[10,6,5,5],
-"structpw__map__range.html#a96ecc91bdc991ce5c807a1b79aded4f4":[10,6,5,5,1],
-"structpw__map__range.html#aaf1ff0e5b8623a1c64ee4ac9dbf2008a":[10,6,5,5,0],
-"structpw__memblock.html":[10,6,5,2],
-"structpw__memblock.html#a1ca99934939d8b89c158a0256d6d906c":[10,6,5,2,1],
-"structpw__memblock.html#a4731883fd9899d0d668c0f44a16d3b33":[10,6,5,2,5],
-"structpw__memblock.html#a66508184497a6f6e211eafa8f6e4edd7":[10,6,5,2,0],
-"structpw__memblock.html#a88d9c260a71ebd2413b9c4f6c6b84889":[10,6,5,2,3],
-"structpw__memblock.html#a8e96a2d24a5fc723b2a637de4bf700b1":[10,6,5,2,6],
-"structpw__memblock.html#a8fb4076dc9a00af2a3da6be6859b6a00":[10,6,5,2,4],
-"structpw__memblock.html#ac130234986a5d662d20a3e593448bbbd":[10,6,5,2,2],
-"structpw__memblock.html#ae9876a344086ff407cf6bf3704b24515":[10,6,5,2,7]
+"structpw__impl__module__events.html":[10,5,6,1]
 };
